package
Version:
v1.5.0
Opens a new window with list of versions in this module.
Published: Oct 29, 2022
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Extends os.FileInfo in order to provide the path too
type Match struct {
LineNumber int
Content string
}
Creates a new match given the line number and the
respective string content
Provides methods for handling output for matches
Source Files
¶
Click to show internal directories.
Click to hide internal directories.